@@ -3,7 +3,7 @@ import uuid
 from django.conf import settings
 from django.contrib import admin, messages
 from django.core.exceptions import ValidationError
-from django.http import HttpResponse
+from django.http import HttpResponse, JsonResponse
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth import get_user_model
 from django.template.response import TemplateResponse
@@ -14,6 +14,8 @@ from django.shortcuts import render, redirect, reverse
 from .generator.forms import QrGenerateForm
 from .generator.zip import generate_qr_zip
 from .models import ApiHit, Department, LinkUrl, QRCode
+from .serializers import ApiHitSerializer
+from rest_framework.renderers import JSONRenderer
 
 User = get_user_model()
 
@@ -36,6 +38,13 @@ class ApiHitAdmin(admin.ModelAdmin):
     change_list_template = 'qrtoolkit_core/apihit/change_list.html'
     list_filter = ('code__department__name',)
 
+    def changelist_view(self, request, extra_context=None):
+        extra_context = extra_context or {}
+        hit_data = ApiHitSerializer(instance=self.get_queryset(request), many=True).data
+        extra_context['hits_json'] = JSONRenderer().render(hit_data).decode('utf-8')
+
+        return super(ApiHitAdmin, self).changelist_view(request, extra_context=extra_context)
+
 
 class LinkUrlInline(admin.StackedInline):
     model = LinkUrl
