@@ -49,7 +49,7 @@ class QRCodeDetails(APIView):
 
         except (QRCode.DoesNotExist or ValidationError) as error:
             hit = ApiHit(code=None, action=ApiHit.ACTION_CHOICES.ERROR,
-                         message=f'code with "{str(short_uuid)}" does not exist.')
+                         message=f'code with id {{{str(short_uuid)}}} does not exist.')
             hit.save()
             raise Http404
 
